==> cms-db_v0.8.1.tar.gz: gb.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

if (!defined('cms-db')) {
	chdir('./admin');
	include('friendlyerror.firewall.inc.php');
	die();
}

if (!isset($gb_data_file)) {
	$gb_data_file = './data/gbfile.csv';
}
if (!isset($gb_output_reverse)) {
	$gb_output_reverse = true;
}

$template->addToHead('<style type="text/css">/* <![CDATA[ */ .input_special { display: none } /* ]]> */</style>');

if (!isset($locale)) {
	chdir('./admin');
	$locale = new LocalizingClass('blog', $locale_default);
	chdir('../');
}

function getNewEntry($name='', $email='', $website='', $text='') {
	global $gbpageid, $id_empty, $id_time;
	include('./data/settings/url.inc.php');
	$time = microtime(true);
	return '<form method="post" action="'.$urlbefore.$gbpageid.$urlafter.'">
	<p>
		<label for="name"><b>'.locale('label_name',true).'</b></label><br />
		<input type="text" id="name" name="name" size="30" maxlength="50" value="'.htmlspecialchars($name).'" /><br />
		<label for="email"><b>'.locale('label_email',true).'</b></label> '.locale('label_not-displayed',true).'<br />
		<input type="text" id="email" name="email" size="30" maxlength="100" value="'.htmlspecialchars($email).'" /><br />
		<label for="website"><b>'.locale('label_website',true).'</b></label> '.locale('label_optional',true).'<br />
		<input type="text" id="website" name="website" size="30" maxlength="100" value="'.htmlspecialchars($website).'" /><br />
		<label for="text"><b>'.locale('label_text',true).'</b></label><br />
		<textarea id="text" name="text" rows="10" cols="60" style="width:100%">'.htmlspecialchars($text).'</textarea>
		<input type="text" name="'.$id_empty.'" value="" size="1" class="input_special" />
		<input type="text" name="'.$id_time.'" value="'.$time.'" size="1" class="input_special" />
	</p>
	<p>
		<input type="submit" value="'.locale('button_send',true).'" name="CMS-DB_GB_SENT" />
		<input type="reset" value="'.locale('button_reset',true).'" />
	</p>
</form>';
}

$gbpageid = $_SERVER['QUERY_STRING'];
$id_time = sprintf('%x', crc32($_SERVER['SCRIPT_FILENAME'].'?'.$gbpageid.'1'));
$id_empty = sprintf('%x', crc32($_SERVER['SCRIPT_FILENAME'].'?'.$gbpageid.'2'));


// Spam-Schutz: Spezielle Felder müssen existieren
if (isset($_POST['CMS-DB_GB_SENT']) && isset($_POST[$id_empty]) && isset($_POST[$id_time])) {
	include('./admin/escape.inc.php');
	$array = array("\n","\r");
	$zahl = $_POST['zahl'];
	$name = $_POST['name'];
	$name = str_replace($array, '', $name);
	$name = escapeSL($name);
	$name = htmlspecialchars($name);
	$email = $_POST['email'];
	$email = str_replace($array, '', $email);
	$email = escapeSL($email);
	$email = htmlspecialchars($email);
	$website = $_POST['website'];
	$website = str_replace($array, '', $website);
	$website = escapeSL($website);
	$website = htmlspecialchars($website);
	$text = $_POST['text'];
	$text = escapeSL($text);
	$text = htmlspecialchars($text);
	$text = nl2br($text);
	$text = str_replace($array, '', $text);
	$time = time();
	//$time = date('H:i:s');
	//$date = date('d.m.Y');

	if($name != '' && $email != '' && strpos($email, '@') !== false && strpos($email, '.') !== false && $text != '') {
		$time_old = $_POST[$id_time];
		$time_now = microtime(true);
		$time_difference = $time_now-$time_old;
		/* 
		 * Spam-Schutz:
		 * Feld darf nicht von "blödem" Bot ausgefüllt werden,
		 * mindestens 10 Sekunden zum Schreiben des Textes
		 */
		if ($_POST[$id_empty] == '' && $time_difference > 10) {
			$list = '"'.$name.'","'.$email.'","'.$text.'","'.$time.'","'.$website.'"';
			$list.= "\n";

			$fp = fopen($gb_data_file, 'a+');
			fwrite($fp, $list);
			fclose($fp);
			
			$form = '<p class="success">'.locale('desc_saved',true).'</p>';
		} else {
			$form = '<p class="error">Error '.round($time_difference).'</p>';
		}
	} else {
		$form = '<p class="error">'.locale('desc_error-input',true).'</p>';
		$form.= getNewEntry(escapeSL($_POST['name']),escapeSL($_POST['email']),escapeSL($_POST['website']),escapeSL($_POST['text']));
	}
} else {
	$form = getNewEntry();
}

if ($gb_output_reverse) echo $form;

if (file_exists($gb_data_file)) {
	$handle = fopen ($gb_data_file, "r");
	while ( ($data = fgetcsv ($handle, 1000, ",")) !== FALSE ) {
		$entries[] = $data;
	}
	fclose ($handle);
	if ($entries) {
		if ($gb_output_reverse) $entries = array_reverse($entries, true);
		$i = 0;
		foreach($entries as $data) {
			$gb_name = $data[0];
			$gb_email = $data[1];
			$gb_text = $data[2];
			if (strpos($data[3], ':') === false) {
				$gb_time = date('H:i:s', $data[3]);
				$gb_date = date('d.m.Y', $data[3]);
				$gb_website = $data[4];
			} else {
				$gb_time = $data[3];
				$gb_date = $data[4];
				$gb_website = '';
			}
			if ($gb_website != '') {
				if (substr($gb_website, 0, 4) != 'http') {
					$gb_website = 'http://'.$gb_website;
				}
				$gb_name = '<a href="'.$gb_website.'">'.$gb_name.'</a>';
			}
			$i++;
			if (!$gb_output_reverse) {
				$count = '<span class="commentcount">#'.$i.'</span> ';
			} else {
				$count = '';
			}
			$classname = (($i&1) == 1) ? 'odd' : 'even';
			echo '<p class="comment '.$classname.'">';
			echo '<div class="commentheader">'.$count.'<span class="commentmeta">'.sprintf(locale('desc_meta',true), $gb_name, $gb_date, $gb_time).'</span></div>';
			echo '<div class="commentcontent">'.$gb_text.'</div></p>';
		}
	} else {
		echo '<p>'.locale('desc_no-entries',true).'</p>';
	}
} else {
	echo '<p>'.locale('desc_no-entries',true).'</p>';
}

if (!$gb_output_reverse) echo $form;

if (!isset($blog)) {
	unset($locale);
}
?>

==> cms-db_v0.9.tar.gz: gb.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

if (!defined('cms-db')) {
	chdir('./admin');
	include('friendlyerror.firewall.inc.php');
	die();
}

if (!isset($gb_data_file)) {
	$gb_data_file = './data/gbfile.csv';
}
if (!isset($gb_output_reverse)) {
	$gb_output_reverse = true;
}

$template->addToHead('<style type="text/css">/* <![CDATA[ */ .input_special { display: none } /* ]]> */</style>');

if (!isset($locale)) {
	chdir('./admin');
	$locale = new LocalizingClass('blog', $locale_default);
	chdir('../');
}

function getNewEntry($name='', $email='', $website='', $text='') {
	global $gbpageid, $id_empty, $id_time;
	include('./data/settings/url.inc.php');
	$time = microtime(true);
	return '<form method="post" action="'.$urlbefore.$gbpageid.$urlafter.'">
	<p>
		<label for="name"><b>'.locale('label_name',true).'</b></label><br />
		<input type="text" id="name" name="name" size="30" maxlength="50" value="'.htmlspecialchars($name).'" /><br />
		<label for="email"><b>'.locale('label_email',true).'</b></label> '.locale('label_not-displayed',true).'<br />
		<input type="text" id="email" name="email" size="30" maxlength="100" value="'.htmlspecialchars($email).'" /><br />
		<label for="website"><b>'.locale('label_website',true).'</b></label> '.locale('label_optional',true).'<br />
		<input type="text" id="website" name="website" size="30" maxlength="100" value="'.htmlspecialchars($website).'" /><br />
		<label for="text"><b>'.locale('label_text',true).'</b></label><br />
		<textarea id="text" name="text" rows="10" cols="60" style="width:100%">'.htmlspecialchars($text).'</textarea>
		<input type="text" name="'.$id_empty.'" value="" size="1" class="input_special" />
		<input type="text" name="'.$id_time.'" value="'.$time.'" size="1" class="input_special" />
	</p>
	<p>
		<input type="submit" value="'.locale('button_send',true).'" name="CMS-DB_GB_SENT" />
		<input type="reset" value="'.locale('button_reset',true).'" />
	</p>
</form>';
}

$gbpageid = $_SERVER['QUERY_STRING'];
$id_time = sprintf('%x', crc32($_SERVER['SCRIPT_FILENAME'].'?'.$gbpageid.'1'));
$id_empty = sprintf('%x', crc32($_SERVER['SCRIPT_FILENAME'].'?'.$gbpageid.'2'));


// Spam-Schutz: Spezielle Felder müssen existieren
if (isset($_POST['CMS-DB_GB_SENT']) && isset($_POST[$id_empty]) && isset($_POST[$id_time])) {
	include('./admin/escape.inc.php');
	$array = array("\n", "\r");
	$name = $_POST['name'];
	$name = str_replace($array, '', $name);
	$name = escapeSL($name);
	$name = htmlspecialchars($name);
	$email = $_POST['email'];
	$email = str_replace($array, '', $email);
	$email = escapeSL($email);
	$email = htmlspecialchars($email);
	$website = $_POST['website'];
	$website = str_replace($array, '', $website);
	$website = escapeSL($website);
	$website = htmlspecialchars($website);
	$text = $_POST['text'];
	$text = escapeSL($text);
	$text = htmlspecialchars($text);
	$text = nl2br($text);
	$text = str_replace($array, '', $text);
	$time = time();
	//$time = date('H:i:s');
	//$date = date('d.m.Y');

	if($name != '' && $email != '' && strpos($email, '@') !== false && strpos($email, '.') !== false && $text != '') {
		$time_old = $_POST[$id_time];
		$time_now = microtime(true);
		$time_difference = $time_now-$time_old;
		/* 
		 * Spam-Schutz:
		 * Feld darf nicht von "blödem" Bot ausgefüllt werden,
		 * mindestens 10 Sekunden zum Schreiben des Textes
		 */
		if ($_POST[$id_empty] == '' && $time_difference > 10) {
			$list = '"'.$name.'","'.$email.'","'.$text.'","'.$time.'","'.$website.'"';
			$list.= "\n";

			$fp = fopen($gb_data_file, 'a+');
			fwrite($fp, $list);
			fclose($fp);
			
			$form = '<p class="success">'.locale('desc_saved',true).'</p>';
		} else {
			$form = '<p class="error">'.locale('desc_error-spamprotection',true).'</p>';
			$form.= getNewEntry(escapeSL($_POST['name']),escapeSL($_POST['email']),escapeSL($_POST['website']),escapeSL($_POST['text']));
		}
	} else {
		$errors = array();
		if ($name == '') $errors[] = locale('desc_error-missing-list-name',true);
		if (strpos($email, '@') === false or strpos($email, '.') === false) $errors[] = locale('desc_error-missing-list-email',true);
		if ($text == '') $errors[] = locale('desc_error-missing-list-text',true);
		$errors = '<br />&bull; '.implode('<br />&bull; ', $errors);
		$form = '<p class="error">'.locale('desc_error-input',true).' '.$errors.'</p>';
		$form.= getNewEntry(escapeSL($_POST['name']),escapeSL($_POST['email']),escapeSL($_POST['website']),escapeSL($_POST['text']));
	}
} else {
	$form = getNewEntry();
}

if ($gb_output_reverse) echo $form;

if (file_exists($gb_data_file)) {
	$entries = array();
	// possible alternative for reversing: $h = popen('tac file', 'r');
	$handle = fopen($gb_data_file, "r");
	while ( ($data = fgetcsv ($handle, 1000, ",")) !== FALSE ) {
		$entries[] = $data;
	}
	fclose($handle);
	if (count($entries) != 0) {
		if ($gb_output_reverse) $entries = array_reverse($entries, true);
		$i = 0;
		foreach($entries as $data) {
			$gb_name = $data[0];
			$gb_email = $data[1];
			$gb_text = $data[2];
			if (strpos($data[3], ':') === false) {
				$gb_time = date('H:i:s', $data[3]);
				$gb_date = date('d.m.Y', $data[3]);
				$gb_website = $data[4];
			} else {
				$gb_time = $data[3];
				$gb_date = $data[4];
				$gb_website = '';
			}
			if ($gb_website != '') {
				if (substr($gb_website, 0, 4) != 'http') {
					$gb_website = 'http://'.$gb_website;
				}
				$gb_name = '<a href="'.$gb_website.'">'.$gb_name.'</a>';
			}
			$i++;
			if (!$gb_output_reverse) {
				$count = '<span class="commentcount">#'.$i.'</span> ';
			} else {
				$count = '';
			}
			$classname = (($i&1) == 1) ? 'odd' : 'even';
			echo '<p class="comment '.$classname.'">';
			echo '<div class="commentheader">'.$count.'<span class="commentmeta">'.sprintf(locale('desc_meta',true), $gb_name, $gb_date, $gb_time).'</span></div>';
			echo '<div class="commentcontent">'.$gb_text.'</div></p>';
		}
	} else {
		echo '<p>'.locale('desc_no-entries',true).'</p>';
	}
} else {
	echo '<p>'.locale('desc_no-entries',true).'</p>';
}

if (!$gb_output_reverse) echo $form;

if (!isset($blog)) {
	unset($locale);
}
?>
